@@ -19,6 +19,7 @@ import java.util.Collections;
 import java.util.HashMap;
 import java.util.HashSet;
 import java.util.Iterator;
+import java.util.LinkedHashMap;
 import java.util.List;
 import java.util.Map;
 import java.util.Set;
@@ -28,10 +29,15 @@ final class SimpleConfigObject extends AbstractConfigObject implements Serializa
     private final Map<String, AbstractConfigValue> value;
     private final boolean resolved;
     private final boolean ignoresFallbacks;
-    private static final SimpleConfigObject EMPTY_INSTANCE = empty(SimpleConfigOrigin.newSimple("empty config"));
+    private static final SimpleConfigObject EMPTY_INSTANCE =
+            empty(SimpleConfigOrigin.newSimple("empty config"));
     private static final int HASH_CODE = 41;
 
-    SimpleConfigObject(ConfigOrigin origin, Map<String, AbstractConfigValue> value, ResolveStatus status, boolean ignoresFallbacks) {
+    SimpleConfigObject(
+            ConfigOrigin origin,
+            Map<String, AbstractConfigValue> value,
+            ResolveStatus status,
+            boolean ignoresFallbacks) {
         super(origin);
         if (value == null) {
             throw new ConfigException.BugOrBroken("creating config object with null map");
@@ -69,12 +75,24 @@ final class SimpleConfigObject extends AbstractConfigObject implements Serializa
             }
         }
 
-        return v == null ? null : new SimpleConfigObject(this.origin(), Collections.singletonMap(key, v), v.resolveStatus(), this.ignoresFallbacks);
+        return v == null
+                ? null
+                : new SimpleConfigObject(
+                        this.origin(),
+                        Collections.singletonMap(key, v),
+                        v.resolveStatus(),
+                        this.ignoresFallbacks);
     }
 
     SimpleConfigObject withOnlyPath(Path path) {
         SimpleConfigObject o = this.withOnlyPathOrNull(path);
-        return o == null ? new SimpleConfigObject(this.origin(), Collections.emptyMap(), ResolveStatus.RESOLVED, this.ignoresFallbacks) : o;
+        return o == null
+                ? new SimpleConfigObject(
+                        this.origin(),
+                        Collections.emptyMap(),
+                        ResolveStatus.RESOLVED,
+                        this.ignoresFallbacks)
+                : o;
     }
 
     SimpleConfigObject withoutPath(Path path) {
@@ -84,19 +102,30 @@ final class SimpleConfigObject extends AbstractConfigObject implements Serializa
         HashMap<String, AbstractConfigValue> smaller;
         if (next != null && v instanceof AbstractConfigObject) {
             v = ((AbstractConfigObject) v).withoutPath(next);
-            smaller = new HashMap<>(this.value);
+            smaller = new LinkedHashMap<>(this.value);
             smaller.put(key, v);
-            return new SimpleConfigObject(this.origin(), smaller, ResolveStatus.fromValues(smaller.values()), this.ignoresFallbacks);
+            return new SimpleConfigObject(
+                    this.origin(),
+                    smaller,
+                    ResolveStatus.fromValues(smaller.values()),
+                    this.ignoresFallbacks);
         } else if (next == null && v != null) {
-            smaller = new HashMap<>(this.value.size() - 1);
+            smaller = new LinkedHashMap<>(this.value.size() - 1);
 
-            for (Entry<String, AbstractConfigValue> stringAbstractConfigValueEntry : this.value.entrySet()) {
+            for (Entry<String, AbstractConfigValue> stringAbstractConfigValueEntry :
+                    this.value.entrySet()) {
                 if (!stringAbstractConfigValueEntry.getKey().equals(key)) {
-                    smaller.put(stringAbstractConfigValueEntry.getKey(), stringAbstractConfigValueEntry.getValue());
+                    smaller.put(
+                            stringAbstractConfigValueEntry.getKey(),
+                            stringAbstractConfigValueEntry.getValue());
                 }
             }
 
-            return new SimpleConfigObject(this.origin(), smaller, ResolveStatus.fromValues(smaller.values()), this.ignoresFallbacks);
+            return new SimpleConfigObject(
+                    this.origin(),
+                    smaller,
+                    ResolveStatus.fromValues(smaller.values()),
+                    this.ignoresFallbacks);
         } else {
             return this;
         }
@@ -104,17 +133,22 @@ final class SimpleConfigObject extends AbstractConfigObject implements Serializa
 
     public SimpleConfigObject withValue(String key, ConfigValue v) {
         if (v == null) {
-            throw new ConfigException.BugOrBroken("Trying to store null ConfigValue in a ConfigObject");
+            throw new ConfigException.BugOrBroken(
+                    "Trying to store null ConfigValue in a ConfigObject");
         } else {
             Map newMap;
             if (this.value.isEmpty()) {
                 newMap = Collections.singletonMap(key, (AbstractConfigValue) v);
             } else {
-                newMap = new HashMap<>(this.value);
+                newMap = new LinkedHashMap<>(this.value);
                 newMap.put(key, v);
             }
 
-            return new SimpleConfigObject(this.origin(), newMap, ResolveStatus.fromValues(newMap.values()), this.ignoresFallbacks);
+            return new SimpleConfigObject(
+                    this.origin(),
+                    newMap,
+                    ResolveStatus.fromValues(newMap.values()),
+                    this.ignoresFallbacks);
         }
     }
 
@@ -128,7 +162,12 @@ final class SimpleConfigObject extends AbstractConfigObject implements Serializa
             if (child instanceof AbstractConfigObject) {
                 return this.withValue(key, ((AbstractConfigObject) child).withValue(next, v));
             } else {
-                SimpleConfig subtree = ((AbstractConfigValue) v).atPath(SimpleConfigOrigin.newSimple("withValue(" + next.render() + ")"), next);
+                SimpleConfig subtree =
+                        ((AbstractConfigValue) v)
+                                .atPath(
+                                        SimpleConfigOrigin.newSimple(
+                                                "withValue(" + next.render() + ")"),
+                                        next);
                 return this.withValue(key, subtree.root());
             }
         }
@@ -138,7 +177,8 @@ final class SimpleConfigObject extends AbstractConfigObject implements Serializa
         return this.value.get(key);
     }
 
-    private SimpleConfigObject newCopy(ResolveStatus newStatus, ConfigOrigin newOrigin, boolean newIgnoresFallbacks) {
+    private SimpleConfigObject newCopy(
+            ResolveStatus newStatus, ConfigOrigin newOrigin, boolean newIgnoresFallbacks) {
         return new SimpleConfigObject(newOrigin, this.value, newStatus, newIgnoresFallbacks);
     }
 
@@ -147,21 +187,25 @@ final class SimpleConfigObject extends AbstractConfigObject implements Serializa
     }
 
     protected SimpleConfigObject withFallbacksIgnored() {
-        return this.ignoresFallbacks ? this : this.newCopy(this.resolveStatus(), this.origin(), true);
+        return this.ignoresFallbacks
+                ? this
+                : this.newCopy(this.resolveStatus(), this.origin(), true);
     }
 
     ResolveStatus resolveStatus() {
         return ResolveStatus.fromBoolean(this.resolved);
     }
 
-    public SimpleConfigObject replaceChild(AbstractConfigValue child, AbstractConfigValue replacement) {
-        Map<String, AbstractConfigValue> newChildren = new HashMap<>(this.value);
+    public SimpleConfigObject replaceChild(
+            AbstractConfigValue child, AbstractConfigValue replacement) {
+        Map<String, AbstractConfigValue> newChildren = new LinkedHashMap<>(this.value);
         Iterator<Entry<String, AbstractConfigValue>> var4 = newChildren.entrySet().iterator();
 
         Entry<String, AbstractConfigValue> old;
         do {
             if (!var4.hasNext()) {
-                throw new ConfigException.BugOrBroken("SimpleConfigObject.replaceChild did not find " + child + " in " + this);
+                throw new ConfigException.BugOrBroken(
+                        "SimpleConfigObject.replaceChild did not find " + child + " in " + this);
             }
 
             old = var4.next();
@@ -173,7 +217,11 @@ final class SimpleConfigObject extends AbstractConfigObject implements Serializa
             newChildren.remove(old.getKey());
         }
 
-        return new SimpleConfigObject(this.origin(), newChildren, ResolveStatus.fromValues(newChildren.values()), this.ignoresFallbacks);
+        return new SimpleConfigObject(
+                this.origin(),
+                newChildren,
+                ResolveStatus.fromValues(newChildren.values()),
+                this.ignoresFallbacks);
     }
 
     public boolean hasDescendant(AbstractConfigValue descendant) {
@@ -190,7 +238,8 @@ final class SimpleConfigObject extends AbstractConfigObject implements Serializa
                     }
 
                     child = var2.next();
-                } while (!(child instanceof Container) || !((Container) child).hasDescendant(descendant));
+                } while (!(child instanceof Container)
+                        || !((Container) child).hasDescendant(descendant));
 
                 return true;
             }
@@ -206,10 +255,13 @@ final class SimpleConfigObject extends AbstractConfigObject implements Serializa
     }
 
     public Map<String, Object> unwrapped() {
-        Map<String, Object> m = new HashMap<>();
+        Map<String, Object> m = new LinkedHashMap<>();
 
-        for (Entry<String, AbstractConfigValue> stringAbstractConfigValueEntry : this.value.entrySet()) {
-            m.put(stringAbstractConfigValueEntry.getKey(), stringAbstractConfigValueEntry.getValue().unwrapped());
+        for (Entry<String, AbstractConfigValue> stringAbstractConfigValueEntry :
+                this.value.entrySet()) {
+            m.put(
+                    stringAbstractConfigValueEntry.getKey(),
+                    stringAbstractConfigValueEntry.getValue().unwrapped());
         }
 
         return m;
@@ -218,12 +270,13 @@ final class SimpleConfigObject extends AbstractConfigObject implements Serializa
     protected SimpleConfigObject mergedWithObject(AbstractConfigObject abstractFallback) {
         this.requireNotIgnoringFallbacks();
         if (!(abstractFallback instanceof SimpleConfigObject)) {
-            throw new ConfigException.BugOrBroken("should not be reached (merging non-SimpleConfigObject)");
+            throw new ConfigException.BugOrBroken(
+                    "should not be reached (merging non-SimpleConfigObject)");
         } else {
             SimpleConfigObject fallback = (SimpleConfigObject) abstractFallback;
             boolean changed = false;
             boolean allResolved = true;
-            Map<String, AbstractConfigValue> merged = new HashMap<>();
+            Map<String, AbstractConfigValue> merged = new LinkedHashMap<>();
             Set<String> allKeys = new HashSet<>();
             allKeys.addAll(this.keySet());
             allKeys.addAll(fallback.keySet());
@@ -253,8 +306,13 @@ final class SimpleConfigObject extends AbstractConfigObject implements Serializa
             ResolveStatus newResolveStatus = ResolveStatus.fromBoolean(allResolved);
             boolean newIgnoresFallbacks = fallback.ignoresFallbacks();
             if (changed) {
-                return new SimpleConfigObject(mergeOrigins(this, fallback), merged, newResolveStatus, newIgnoresFallbacks);
-            } else if (newResolveStatus == this.resolveStatus() && newIgnoresFallbacks == this.ignoresFallbacks()) {
+                return new SimpleConfigObject(
+                        mergeOrigins(this, fallback),
+                        merged,
+                        newResolveStatus,
+                        newIgnoresFallbacks);
+            } else if (newResolveStatus == this.resolveStatus()
+                    && newIgnoresFallbacks == this.ignoresFallbacks()) {
                 return this;
             } else {
                 return this.newCopy(newResolveStatus, this.origin(), newIgnoresFallbacks);
@@ -280,7 +338,7 @@ final class SimpleConfigObject extends AbstractConfigObject implements Serializa
             AbstractConfigValue modified = modifier.modifyChildMayThrow(k, v);
             if (modified != v) {
                 if (changes == null) {
-                    changes = new HashMap<>();
+                    changes = new LinkedHashMap<>();
                 }
 
                 changes.put(k, modified);
@@ -290,7 +348,7 @@ final class SimpleConfigObject extends AbstractConfigObject implements Serializa
         if (changes == null) {
             return this;
         } else {
-            Map<String, AbstractConfigValue> modified = new HashMap<>();
+            Map<String, AbstractConfigValue> modified = new LinkedHashMap<>();
             boolean sawUnresolved = false;
 
             for (String k : this.keySet()) {
@@ -312,18 +370,24 @@ final class SimpleConfigObject extends AbstractConfigObject implements Serializa
                 }
             }
 
-            return new SimpleConfigObject(this.origin(), modified, sawUnresolved ? ResolveStatus.UNRESOLVED : ResolveStatus.RESOLVED, this.ignoresFallbacks());
+            return new SimpleConfigObject(
+                    this.origin(),
+                    modified,
+                    sawUnresolved ? ResolveStatus.UNRESOLVED : ResolveStatus.RESOLVED,
+                    this.ignoresFallbacks());
         }
     }
 
-    ResolveResult<? extends AbstractConfigObject> resolveSubstitutions(ResolveContext context, ResolveSource source) throws NotPossibleToResolve {
+    ResolveResult<? extends AbstractConfigObject> resolveSubstitutions(
+            ResolveContext context, ResolveSource source) throws NotPossibleToResolve {
         if (this.resolveStatus() == ResolveStatus.RESOLVED) {
             return ResolveResult.make(context, this);
         } else {
             ResolveSource sourceWithParent = source.pushParent(this);
 
             try {
-                SimpleConfigObject.ResolveModifier modifier = new SimpleConfigObject.ResolveModifier(context, sourceWithParent);
+                SimpleConfigObject.ResolveModifier modifier =
+                        new SimpleConfigObject.ResolveModifier(context, sourceWithParent);
                 AbstractConfigValue value = this.modifyMayThrow(modifier);
                 return ResolveResult.make(modifier.context, value).asObjectResult();
             } catch (NotPossibleToResolve | RuntimeException var6) {
@@ -335,14 +399,16 @@ final class SimpleConfigObject extends AbstractConfigObject implements Serializa
     }
 
     SimpleConfigObject relativized(final Path prefix) {
-        return this.modify(new NoExceptionsModifier() {
-            public AbstractConfigValue modifyChild(String key, AbstractConfigValue v) {
-                return v.relativized(prefix);
-            }
-        });
+        return this.modify(
+                new NoExceptionsModifier() {
+                    public AbstractConfigValue modifyChild(String key, AbstractConfigValue v) {
+                        return v.relativized(prefix);
+                    }
+                });
     }
 
-    protected void render(StringBuilder sb, int indent, boolean atRoot, ConfigRenderOptions options) {
+    protected void render(
+            StringBuilder sb, int indent, boolean atRoot, ConfigRenderOptions options) {
         if (this.isEmpty()) {
             sb.append("{}");
         } else {
@@ -423,7 +489,6 @@ final class SimpleConfigObject extends AbstractConfigObject implements Serializa
         if (atRoot && options.getFormatted()) {
             sb.append('\n');
         }
-
     }
 
     public AbstractConfigValue get(Object key) {
@@ -447,7 +512,6 @@ final class SimpleConfigObject extends AbstractConfigObject implements Serializa
 
                     key = var4.next();
                 } while (a.get(key).equals(b.get(key)));
-
             }
             return false;
         }
@@ -460,7 +524,9 @@ final class SimpleConfigObject extends AbstractConfigObject implements Serializa
         int valuesHash = 0;
 
         String k;
-        for (Iterator<String> var3 = keys.iterator(); var3.hasNext(); valuesHash += m.get(k).hashCode()) {
+        for (Iterator<String> var3 = keys.iterator();
+                var3.hasNext();
+                valuesHash += m.get(k).hashCode()) {
             k = var3.next();
         }
 
@@ -498,8 +564,12 @@ final class SimpleConfigObject extends AbstractConfigObject implements Serializa
     public Set<Entry<String, ConfigValue>> entrySet() {
         HashSet<Entry<String, ConfigValue>> entries = new HashSet<>();
 
-        for (Entry<String, AbstractConfigValue> stringAbstractConfigValueEntry : this.value.entrySet()) {
-            entries.add(new AbstractMap.SimpleImmutableEntry<>(stringAbstractConfigValueEntry.getKey(), stringAbstractConfigValueEntry.getValue()));
+        for (Entry<String, AbstractConfigValue> stringAbstractConfigValueEntry :
+                this.value.entrySet()) {
+            entries.add(
+                    new AbstractMap.SimpleImmutableEntry<>(
+                            stringAbstractConfigValueEntry.getKey(),
+                            stringAbstractConfigValueEntry.getValue()));
         }
 
         return entries;
@@ -526,7 +596,9 @@ final class SimpleConfigObject extends AbstractConfigObject implements Serializa
     }
 
     static SimpleConfigObject emptyMissing(ConfigOrigin baseOrigin) {
-        return new SimpleConfigObject(SimpleConfigOrigin.newSimple(baseOrigin.description() + " (not found)"), Collections.emptyMap());
+        return new SimpleConfigObject(
+                SimpleConfigOrigin.newSimple(baseOrigin.description() + " (not found)"),
+                Collections.emptyMap());
     }
 
     private Object writeReplace() throws ObjectStreamException {
@@ -544,13 +616,16 @@ final class SimpleConfigObject extends AbstractConfigObject implements Serializa
             this.originalRestrict = context.restrictToChild();
         }
 
-        public AbstractConfigValue modifyChildMayThrow(String key, AbstractConfigValue v) throws NotPossibleToResolve {
+        public AbstractConfigValue modifyChildMayThrow(String key, AbstractConfigValue v)
+                throws NotPossibleToResolve {
             if (this.context.isRestrictedToChild()) {
                 if (key.equals(this.context.restrictToChild().first())) {
                     Path remainder = this.context.restrictToChild().remainder();
                     if (remainder != null) {
-                        ResolveResult<? extends AbstractConfigValue> result = this.context.restrict(remainder).resolve(v, this.source);
-                        this.context = result.context.unrestricted().restrict(this.originalRestrict);
+                        ResolveResult<? extends AbstractConfigValue> result =
+                                this.context.restrict(remainder).resolve(v, this.source);
+                        this.context =
+                                result.context.unrestricted().restrict(this.originalRestrict);
                         return result.value;
                     } else {
                         return v;
@@ -559,7 +634,8 @@ final class SimpleConfigObject extends AbstractConfigObject implements Serializa
                     return v;
                 }
             } else {
-                ResolveResult<? extends AbstractConfigValue> result = this.context.unrestricted().resolve(v, this.source);
+                ResolveResult<? extends AbstractConfigValue> result =
+                        this.context.unrestricted().resolve(v, this.source);
                 this.context = result.context.unrestricted().restrict(this.originalRestrict);
                 return result.value;
             }
