@@ -17,15 +17,16 @@
 
 package org.apache.seatunnel.connectors.seatunnel.file.hdfs.source.config;
 
-import static org.apache.hadoop.fs.CommonConfigurationKeysPublic.FS_DEFAULT_NAME_KEY;
-
 import org.apache.seatunnel.api.configuration.Option;
 import org.apache.seatunnel.api.configuration.Options;
 import org.apache.seatunnel.connectors.seatunnel.file.config.BaseSourceConfig;
 
+import static org.apache.hadoop.fs.CommonConfigurationKeysPublic.FS_DEFAULT_NAME_KEY;
+
 public class HdfsSourceConfig extends BaseSourceConfig {
-    public static final Option<String> DEFAULT_FS = Options.key(FS_DEFAULT_NAME_KEY)
-            .stringType()
-            .noDefaultValue()
-            .withDescription("HDFS namenode host");
+    public static final Option<String> DEFAULT_FS =
+            Options.key(FS_DEFAULT_NAME_KEY)
+                    .stringType()
+                    .noDefaultValue()
+                    .withDescription("HDFS namenode host");
 }
