@@ -30,8 +30,6 @@ import org.apache.seatunnel.e2e.common.TestSuiteBase;
 import org.apache.seatunnel.e2e.common.container.TestContainer;
 import org.apache.seatunnel.e2e.common.util.ContainerUtil;
 
-import com.typesafe.config.Config;
-import com.typesafe.config.ConfigFactory;
 import org.awaitility.Awaitility;
 import org.junit.jupiter.api.AfterAll;
 import org.junit.jupiter.api.Assertions;
@@ -44,8 +42,12 @@ import org.testcontainers.containers.Container;
 import org.testcontainers.containers.output.Slf4jLogConsumer;
 import org.testcontainers.lifecycle.Startables;
 import org.testcontainers.shaded.org.apache.commons.io.IOUtils;
+import org.testcontainers.shaded.org.apache.commons.lang3.tuple.Pair;
 import org.testcontainers.utility.DockerLoggerFactory;
 
+import com.typesafe.config.Config;
+import com.typesafe.config.ConfigFactory;
+
 import java.io.File;
 import java.io.IOException;
 import java.io.InputStream;
@@ -72,8 +74,6 @@ import java.util.concurrent.TimeUnit;
 import java.util.stream.Collectors;
 import java.util.stream.Stream;
 
-import scala.Tuple2;
-
 public class ClickhouseIT extends TestSuiteBase implements TestResource {
     private static final Logger LOG = LoggerFactory.getLogger(ClickhouseIT.class);
     private static final String CLICKHOUSE_DOCKER_IMAGE = "yandex/clickhouse-server:latest";
@@ -86,7 +86,8 @@ public class ClickhouseIT extends TestSuiteBase implements TestResource {
     private static final String SINK_TABLE = "sink_table";
     private static final String INSERT_SQL = "insert_sql";
     private static final String COMPARE_SQL = "compare_sql";
-    private static final Tuple2<SeaTunnelRowType, List<SeaTunnelRow>> TEST_DATASET = generateTestDataSet();
+    private static final Pair<SeaTunnelRowType, List<SeaTunnelRow>> TEST_DATASET =
+            generateTestDataSet();
     private static final Config CONFIG = getInitClickhouseConfig();
     private ClickHouseContainer container;
     private Connection connection;
@@ -103,17 +104,20 @@ public class ClickhouseIT extends TestSuiteBase implements TestResource {
     @BeforeAll
     @Override
     public void startUp() throws Exception {
-        this.container = new ClickHouseContainer(CLICKHOUSE_DOCKER_IMAGE)
-            .withNetwork(NETWORK)
-            .withNetworkAliases(HOST)
-            .withLogConsumer(new Slf4jLogConsumer(DockerLoggerFactory.getLogger(CLICKHOUSE_DOCKER_IMAGE)));
+        this.container =
+                new ClickHouseContainer(CLICKHOUSE_DOCKER_IMAGE)
+                        .withNetwork(NETWORK)
+                        .withNetworkAliases(HOST)
+                        .withLogConsumer(
+                                new Slf4jLogConsumer(
+                                        DockerLoggerFactory.getLogger(CLICKHOUSE_DOCKER_IMAGE)));
         Startables.deepStart(Stream.of(this.container)).join();
         LOG.info("Clickhouse container started");
         Awaitility.given()
-            .ignoreExceptions()
-            .await()
-            .atMost(360L, TimeUnit.SECONDS)
-            .untilAsserted(this::initConnection);
+                .ignoreExceptions()
+                .await()
+                .atMost(360L, TimeUnit.SECONDS)
+                .untilAsserted(this::initConnection);
         this.initializeClickhouseTable();
         this.batchInsertData();
     }
@@ -128,17 +132,24 @@ public class ClickhouseIT extends TestSuiteBase implements TestResource {
         }
     }
 
-    private void initConnection() throws SQLException, ClassNotFoundException, InstantiationException, IllegalAccessException {
+    private void initConnection()
+            throws SQLException, ClassNotFoundException, InstantiationException,
+                    IllegalAccessException {
         final Properties info = new Properties();
         info.put("user", this.container.getUsername());
         info.put("password", this.container.getPassword());
-        this.connection = ((Driver) Class.forName(DRIVER_CLASS).newInstance()).connect(this.container.getJdbcUrl(), info);
+        this.connection =
+                ((Driver) Class.forName(DRIVER_CLASS).newInstance())
+                        .connect(this.container.getJdbcUrl(), info);
     }
 
     private static Config getInitClickhouseConfig() {
         File file = ContainerUtil.getResourcesFile(INIT_CLICKHOUSE_PATH);
         Config config = ConfigFactory.parseFile(file);
-        assert config.hasPath(SOURCE_TABLE) && config.hasPath(SINK_TABLE) && config.hasPath(INSERT_SQL) && config.hasPath(COMPARE_SQL);
+        assert config.hasPath(SOURCE_TABLE)
+                && config.hasPath(SINK_TABLE)
+                && config.hasPath(INSERT_SQL)
+                && config.hasPath(COMPARE_SQL);
         return config;
     }
 
@@ -171,7 +182,8 @@ public class ClickhouseIT extends TestSuiteBase implements TestResource {
             elements = (Double[]) value;
         }
         if (sqlType == null) {
-            throw new IllegalArgumentException("array inject error, not supported data type: " + value.getClass());
+            throw new IllegalArgumentException(
+                    "array inject error, not supported data type: " + value.getClass());
         }
         return connection.createArrayOf(sqlType, elements);
     }
@@ -182,7 +194,7 @@ public class ClickhouseIT extends TestSuiteBase implements TestResource {
         try {
             this.connection.setAutoCommit(true);
             preparedStatement = this.connection.prepareStatement(sql);
-            for (SeaTunnelRow row : TEST_DATASET._2()) {
+            for (SeaTunnelRow row : TEST_DATASET.getValue()) {
                 preparedStatement.setLong(1, (Long) row.getField(0));
                 preparedStatement.setObject(2, row.getField(1));
                 preparedStatement.setArray(3, toSqlArray(row.getField(2)));
@@ -201,7 +213,8 @@ public class ClickhouseIT extends TestSuiteBase implements TestResource {
                 preparedStatement.setDouble(16, (Double) row.getField(15));
                 preparedStatement.setBigDecimal(17, (BigDecimal) row.getField(16));
                 preparedStatement.setDate(18, Date.valueOf((LocalDate) row.getField(17)));
-                preparedStatement.setTimestamp(19, Timestamp.valueOf((LocalDateTime) row.getField(18)));
+                preparedStatement.setTimestamp(
+                        19, Timestamp.valueOf((LocalDateTime) row.getField(18)));
                 preparedStatement.setInt(20, (Integer) row.getField(19));
                 preparedStatement.setString(21, (String) row.getField(20));
                 preparedStatement.setArray(22, toSqlArray(row.getField(21)));
@@ -230,121 +243,127 @@ public class ClickhouseIT extends TestSuiteBase implements TestResource {
         }
     }
 
-    private static Tuple2<SeaTunnelRowType, List<SeaTunnelRow>> generateTestDataSet() {
-        SeaTunnelRowType rowType = new SeaTunnelRowType(
-            new String[]{
-                "id",
-                "c_map",
-                "c_array_string",
-                "c_array_short",
-                "c_array_int",
-                "c_array_long",
-                "c_array_float",
-                "c_array_double",
-                "c_string",
-                "c_boolean",
-                "c_int8",
-                "c_int16",
-                "c_int32",
-                "c_int64",
-                "c_float32",
-                "c_float64",
-                "c_decimal",
-                "c_date",
-                "c_datetime",
-                "c_nullable",
-                "c_lowcardinality",
-                "c_nested.int",
-                "c_nested.double",
-                "c_nested.string",
-                "c_int128",
-                "c_uint128",
-                "c_int256",
-                "c_uint256",
-                "c_point",
-                "c_ring"
-            },
-            new SeaTunnelDataType[]{
-                BasicType.LONG_TYPE,
-                new MapType<>(BasicType.STRING_TYPE, BasicType.INT_TYPE),
-                ArrayType.STRING_ARRAY_TYPE,
-                ArrayType.SHORT_ARRAY_TYPE,
-                ArrayType.INT_ARRAY_TYPE,
-                ArrayType.LONG_ARRAY_TYPE,
-                ArrayType.FLOAT_ARRAY_TYPE,
-                ArrayType.DOUBLE_ARRAY_TYPE,
-                BasicType.STRING_TYPE,
-                BasicType.BOOLEAN_TYPE,
-                BasicType.BYTE_TYPE,
-                BasicType.SHORT_TYPE,
-                BasicType.INT_TYPE,
-                BasicType.LONG_TYPE,
-                BasicType.FLOAT_TYPE,
-                BasicType.DOUBLE_TYPE,
-                new DecimalType(9, 4),
-                LocalTimeType.LOCAL_DATE_TYPE,
-                LocalTimeType.LOCAL_DATE_TIME_TYPE,
-                BasicType.INT_TYPE,
-                BasicType.STRING_TYPE,
-                ArrayType.INT_ARRAY_TYPE,
-                ArrayType.DOUBLE_ARRAY_TYPE,
-                ArrayType.STRING_ARRAY_TYPE,
-                BasicType.STRING_TYPE,
-                BasicType.STRING_TYPE,
-                BasicType.STRING_TYPE,
-                BasicType.STRING_TYPE,
-                BasicType.STRING_TYPE,
-                BasicType.STRING_TYPE
-            });
+    private static Pair<SeaTunnelRowType, List<SeaTunnelRow>> generateTestDataSet() {
+        SeaTunnelRowType rowType =
+                new SeaTunnelRowType(
+                        new String[] {
+                            "id",
+                            "c_map",
+                            "c_array_string",
+                            "c_array_short",
+                            "c_array_int",
+                            "c_array_long",
+                            "c_array_float",
+                            "c_array_double",
+                            "c_string",
+                            "c_boolean",
+                            "c_int8",
+                            "c_int16",
+                            "c_int32",
+                            "c_int64",
+                            "c_float32",
+                            "c_float64",
+                            "c_decimal",
+                            "c_date",
+                            "c_datetime",
+                            "c_nullable",
+                            "c_lowcardinality",
+                            "c_nested.int",
+                            "c_nested.double",
+                            "c_nested.string",
+                            "c_int128",
+                            "c_uint128",
+                            "c_int256",
+                            "c_uint256",
+                            "c_point",
+                            "c_ring"
+                        },
+                        new SeaTunnelDataType[] {
+                            BasicType.LONG_TYPE,
+                            new MapType<>(BasicType.STRING_TYPE, BasicType.INT_TYPE),
+                            ArrayType.STRING_ARRAY_TYPE,
+                            ArrayType.SHORT_ARRAY_TYPE,
+                            ArrayType.INT_ARRAY_TYPE,
+                            ArrayType.LONG_ARRAY_TYPE,
+                            ArrayType.FLOAT_ARRAY_TYPE,
+                            ArrayType.DOUBLE_ARRAY_TYPE,
+                            BasicType.STRING_TYPE,
+                            BasicType.BOOLEAN_TYPE,
+                            BasicType.BYTE_TYPE,
+                            BasicType.SHORT_TYPE,
+                            BasicType.INT_TYPE,
+                            BasicType.LONG_TYPE,
+                            BasicType.FLOAT_TYPE,
+                            BasicType.DOUBLE_TYPE,
+                            new DecimalType(9, 4),
+                            LocalTimeType.LOCAL_DATE_TYPE,
+                            LocalTimeType.LOCAL_DATE_TIME_TYPE,
+                            BasicType.INT_TYPE,
+                            BasicType.STRING_TYPE,
+                            ArrayType.INT_ARRAY_TYPE,
+                            ArrayType.DOUBLE_ARRAY_TYPE,
+                            ArrayType.STRING_ARRAY_TYPE,
+                            BasicType.STRING_TYPE,
+                            BasicType.STRING_TYPE,
+                            BasicType.STRING_TYPE,
+                            BasicType.STRING_TYPE,
+                            BasicType.STRING_TYPE,
+                            BasicType.STRING_TYPE
+                        });
         List<SeaTunnelRow> rows = new ArrayList<>();
         for (int i = 0; i < 100; ++i) {
-            SeaTunnelRow row = new SeaTunnelRow(
-                new Object[]{
-                    (long) i,
-                    Collections.singletonMap("key", Integer.parseInt("1")),
-                    new String[]{"string"},
-                    new Short[]{Short.parseShort("1")},
-                    new Integer[]{Integer.parseInt("1")},
-                    new Long[]{Long.parseLong("1")},
-                    new Float[]{Float.parseFloat("1.1")},
-                    new Double[]{Double.parseDouble("1.1")},
-                    "string",
-                    Boolean.FALSE,
-                    Byte.parseByte("1"),
-                    Short.parseShort("1"),
-                    Integer.parseInt("1"),
-                    Long.parseLong("1"),
-                    Float.parseFloat("1.1"),
-                    Double.parseDouble("1.1"),
-                    BigDecimal.valueOf(11L, 1),
-                    LocalDate.now(),
-                    LocalDateTime.now(),
-                    i,
-                    "string",
-                    new Integer[]{Integer.parseInt("1")},
-                    new Double[]{Double.parseDouble("1.1")},
-                    new String[]{"1"},
-                    "170141183460469231731687303715884105727",
-                    "340282366920938463463374607431768211455",
-                    "57896044618658097711785492504343953926634992332820282019728792003956564819967",
-                    "115792089237316195423570985008687907853269984665640564039457584007913129639935",
-                    new double[]{1, 2},
-                    new double[][]{{2, 3}, {4, 5}}
-                });
+            SeaTunnelRow row =
+                    new SeaTunnelRow(
+                            new Object[] {
+                                (long) i,
+                                Collections.singletonMap("key", Integer.parseInt("1")),
+                                new String[] {"string"},
+                                new Short[] {Short.parseShort("1")},
+                                new Integer[] {Integer.parseInt("1")},
+                                new Long[] {Long.parseLong("1")},
+                                new Float[] {Float.parseFloat("1.1")},
+                                new Double[] {Double.parseDouble("1.1")},
+                                "string",
+                                Boolean.FALSE,
+                                Byte.parseByte("1"),
+                                Short.parseShort("1"),
+                                Integer.parseInt("1"),
+                                Long.parseLong("1"),
+                                Float.parseFloat("1.1"),
+                                Double.parseDouble("1.1"),
+                                BigDecimal.valueOf(11L, 1),
+                                LocalDate.now(),
+                                LocalDateTime.now(),
+                                i,
+                                "string",
+                                new Integer[] {Integer.parseInt("1")},
+                                new Double[] {Double.parseDouble("1.1")},
+                                new String[] {"1"},
+                                "170141183460469231731687303715884105727",
+                                "340282366920938463463374607431768211455",
+                                "57896044618658097711785492504343953926634992332820282019728792003956564819967",
+                                "115792089237316195423570985008687907853269984665640564039457584007913129639935",
+                                new double[] {1, 2},
+                                new double[][] {{2, 3}, {4, 5}}
+                            });
             rows.add(row);
         }
-        return Tuple2.apply(rowType, rows);
+        return Pair.of(rowType, rows);
     }
 
     private void compareResult() throws SQLException, IOException {
         String sourceSql = "select * from " + SOURCE_TABLE;
         String sinkSql = "select * from " + SINK_TABLE;
-        List<String> columnList = Arrays.stream(generateTestDataSet()._1().getFieldNames()).collect(Collectors.toList());
+        List<String> columnList =
+                Arrays.stream(generateTestDataSet().getKey().getFieldNames())
+                        .collect(Collectors.toList());
         Statement sourceStatement = connection.createStatement();
         Statement sinkStatement = connection.createStatement();
         ResultSet sourceResultSet = sourceStatement.executeQuery(sourceSql);
         ResultSet sinkResultSet = sinkStatement.executeQuery(sinkSql);
-        Assertions.assertEquals(sourceResultSet.getMetaData().getColumnCount(), sinkResultSet.getMetaData().getColumnCount());
+        Assertions.assertEquals(
+                sourceResultSet.getMetaData().getColumnCount(),
+                sinkResultSet.getMetaData().getColumnCount());
         while (sourceResultSet.next()) {
             if (sinkResultSet.next()) {
                 for (String column : columnList) {
@@ -353,25 +372,25 @@ public class ClickhouseIT extends TestSuiteBase implements TestResource {
                     if (!Objects.deepEquals(source, sink)) {
                         InputStream sourceAsciiStream = sourceResultSet.getBinaryStream(column);
                         InputStream sinkAsciiStream = sinkResultSet.getBinaryStream(column);
-                        String sourceValue = IOUtils.toString(sourceAsciiStream, StandardCharsets.UTF_8);
-                        String sinkValue = IOUtils.toString(sinkAsciiStream, StandardCharsets.UTF_8);
+                        String sourceValue =
+                                IOUtils.toString(sourceAsciiStream, StandardCharsets.UTF_8);
+                        String sinkValue =
+                                IOUtils.toString(sinkAsciiStream, StandardCharsets.UTF_8);
                         Assertions.assertEquals(sourceValue, sinkValue);
                     }
                     Assertions.assertTrue(true);
                 }
             }
         }
-        String columns = String.join(",", generateTestDataSet()._1().getFieldNames());
-        Assertions.assertTrue(compare(String.format(CONFIG.getString(COMPARE_SQL), columns, columns)));
+        String columns = String.join(",", generateTestDataSet().getKey().getFieldNames());
+        Assertions.assertTrue(
+                compare(String.format(CONFIG.getString(COMPARE_SQL), columns, columns)));
     }
 
     private Boolean compare(String sql) {
         try (Statement statement = connection.createStatement()) {
             ResultSet resultSet = statement.executeQuery(sql);
-            while (resultSet.next()) {
-                return false;
-            }
-            return true;
+            return !resultSet.next();
         } catch (SQLException e) {
             throw new RuntimeException("result compare error", e);
         }
